// Example code to convert the old format to the new one

import {
	BingoGame, BingoGoal, BingoGroup
} from '@/js/Bingo.js';
import json from './games.json';
import new_json from './new_games.json';
import {
	instanceToPlain, plainToClass, plainToInstance
} from 'class-transformer';

import markdown_text from '@/js/testmarkdown.js';

export const games: Map<string, BingoGame> = new Map;

function run_old_format() {
	for (const j_game of json) {
		const game = new BingoGame(
			j_game.game_name,
			j_game.game_name,
			'Short Description',
			markdown_text
		);

		for (const j_cat of j_game.categories) {
			const category = new BingoGroup(j_cat.category_name);
			game.addGroup(category);

			for (const j_group of j_cat.groups) {
				const group = new BingoGroup(j_group.group_name, category);
				game.addGroup(group);

				for (const j_goal of j_group.options) {
					const goal = new BingoGoal(j_goal.title, group);
					goal.addTag(j_goal.difficulty);

					game.addGoal(goal);
				}
			}
		}

		games.set(game.name, game);

		for (let i = 0; i < 3; i++)
			games.set(`${ game.name }-${ i }`, game);
	}

	// const game = games.get('Yakuza 0');
	// console.log(instanceToPlain(game));
	// console.log(JSON.stringify(instanceToPlain(game)));

	// const game = games.get('Yakuza 0');
	// const group = game?.getGroupByName('Adventure');
	// if (!group)
	// 	return;

	// const goals = game?.getGoalsByGroup(true, group);
	// console.log(goals);
}

function run_new_format() {
	for (const j_game of new_json) {
		const game = new BingoGame(
			j_game.id,
			j_game.name,
			j_game.short_description,
			j_game.description
		);

		const group_map: Map<string, BingoGroup> = new Map;
		for (const j_group of j_game.groups) {
			let group: BingoGroup;
			if (j_group.parent_id)
				group = new BingoGroup(j_group.name, group_map.get(
					j_group.parent_id
				));
			else
				group = new BingoGroup(j_group.name);

			group_map.set(j_group.name, group);
			game.addGroup(group);
		}

		for (const j_goal of j_game.goals) {
			const group = group_map.get(j_goal.group_id);
			if (!group)
				continue;

			const goal = new BingoGoal(j_goal.name, group);
			goal.possible_spaces = j_goal.possible_spaces;
			goal.tags = j_goal.tags;

			game.addGoal(goal);
		}

		games.set(game.id, game);
	}
}

// run_new_format();
